@@ -88,10 +88,15 @@ class CommandConfig(BaseConfig):
         group.add_argument('--cache', metavar='FILE', help='use FILE as cache database',
                            default=self.cache)
 
+        group = parser.add_argument_group('Authentication')
+        group.add_argument('--smtp-login', action='store_true', help='Enter password for SMTP (store in keyring)')
+        group.add_argument('--telegram-chats', action='store_true', help='List telegram chats the bot is joined to')
+
         group = parser.add_argument_group('job list management')
         group.add_argument('--list', action='store_true', help='list jobs')
         group.add_argument('--add', metavar='JOB', help='add job (key1=value1,key2=value2,...)')
         group.add_argument('--delete', metavar='JOB', help='delete job by location or index')
+        group.add_argument('--test-filter', metavar='JOB', help='test filter output of job by location or index')
         group = parser.add_argument_group('interactive commands ($EDITOR/$VISUAL)')
         group.add_argument('--edit', action='store_true', help='edit URL/job list')
         group.add_argument('--edit-config', action='store_true', help='edit configuration file')
